# TriggerEvent

Condition for the charge to become active. If this field is not specified, the value of the field will be defaulted to the trigger event value defined in the product catalog.  If the value of this field is `SpecificDate`, use the `specificTriggerDate` field to specify the date when the charge becomes active. 

## Enum

* `CONTRACTEFFECTIVE` (value: `'ContractEffective'`)

* `SERVICEACTIVATION` (value: `'ServiceActivation'`)

* `CUSTOMERACCEPTANCE` (value: `'CustomerAcceptance'`)

* `SPECIFICDATE` (value: `'SpecificDate'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


